==> mingw-w64-attica-6.11.0-1.src.tar.zst: attica-6.11.0/src/cloud.h <==
/*
    This file is part of KDE.

    SPDX-FileCopyrightText: 2012 Laszlo Papp <lpapp@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef ATTICA_CLOUD_H
#define ATTICA_CLOUD_H

#include "attica_export.h"

#include <QList>
#include <QSharedDataPointer>
#include <QUrl>

namespace Attica
{

/**
 * @class Cloud cloud.h <Attica/Cloud>
 *
 * Represents a cloud service.
 */
class ATTICA_EXPORT Cloud
{
public:
    typedef QList<Cloud> List;
    class Parser;

    /**
     * Creates an empty Cloud
     */

    Cloud();

    /**
     * Copy constructor.
     * @param other the Cloud to copy from
     */

    Cloud(const Cloud &other);

    /**
     * Assignment operator.
     * @param other the Cloud to assign from
     * @return pointer to this Activity
     */

    Cloud &operator=(const Cloud &other);

    /**
     * Destructor.
     */

    ~Cloud();

    /**
     * Sets the name of the Cloud service
     *
     * @param name the new name
     */

    void setName(const QString &name);

    /**
     * Gets the name of the Cloud service.
     *
     * @return the name
     */

    QString name() const;

    /**
     * Sets the url of the Cloud service
     *
     * @param url the new url
     */

    void setUrl(const QString &url);

    /**
     * Gets the url of the Cloud service.
     *
     * @return the url
     */

    QString url() const;

    /**
     * Sets the icon of the Cloud service
     *
     * @param icon the new icon
     */

    void setIcon(const QUrl &icon);

    /**
     * Gets the icon of the Cloud service.
     *
     * @return the icon
     */

    QUrl icon() const;

    /**
     * Sets the quota of the Cloud service
     *
     * @param quota the new quota
     */

    void setQuota(qulonglong quota);

    /**
     * Gets the quota of the Cloud service.
     *
     * @return the quota
     */

    qulonglong quota() const;

    /**
     * Sets the free amount of the Cloud service
     *
     * @param free the new free amount
     */

    void setFree(qulonglong free);

    /**
     * Gets the free amount of the Cloud service.
     *
     * @return the free amount
     */

    qulonglong free() const;

    /**
     * Sets the used amount of the Cloud service
     *
     * @param used the new used amount
     */

    void setUsed(qulonglong used);

    /**
     * Gets the used amount of the Cloud service.
     *
     * @return the used amount
     */

    qulonglong used() const;

    /**
     * Sets the relative of the Cloud service
     *
     * @param relative the new relative
     */

    void setRelative(float relative);

    /**
     * Gets the relative of the Cloud service.
     *
     * @return the relative
     */

    float relative() const;

    /**
     * Sets the private key of the Cloud service
     *
     * @param privateKey the new privateKey
     */

    void setKey(const QString &privateKey);

    /**
     * Gets the private key of the Cloud service.
     *
     * @return the private key
     */

    QString key() const;

private:
    class Private;
    QSharedDataPointer<Private> d;
};

}

#endif

==> mingw-w64-attica-6.16.0-1.src.tar.zst: attica-6.16.0/src/cloud.h <==
/*
    This file is part of KDE.

    SPDX-FileCopyrightText: 2012 Laszlo Papp <lpapp@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef ATTICA_CLOUD_H
#define ATTICA_CLOUD_H

#include "attica_export.h"

#include <QList>
#include <QSharedDataPointer>
#include <QUrl>

namespace Attica
{

/*!
 * \class Attica::Cloud
 * \inheaderfile Attica/Cloud
 * \inmodule Attica
 *
 * \brief Represents a cloud service.
 */
class ATTICA_EXPORT Cloud
{
public:
    /*!
     *
     */
    typedef QList<Cloud> List;
    class Parser;

    /*!
     * Creates an empty Cloud
     */
    Cloud();

    Cloud(const Cloud &other);

    Cloud &operator=(const Cloud &other);

    ~Cloud();

    /*!
     * Sets the name of the Cloud service
     *
     * \a name the new name
     */
    void setName(const QString &name);

    /*!
     * Returns the name of the Cloud service.
     */
    QString name() const;

    /*!
     * Sets the url of the Cloud service
     *
     * \a url the new url
     */
    void setUrl(const QString &url);

    /*!
     * Returns the url of the Cloud service.
     */
    QString url() const;

    /*!
     * Sets the icon of the Cloud service
     *
     * \a icon the new icon
     */
    void setIcon(const QUrl &icon);

    /*!
     * Returns the icon of the Cloud service.
     */
    QUrl icon() const;

    /*!
     * Sets the quota of the Cloud service
     *
     * \a quota the new quota
     */
    void setQuota(qulonglong quota);

    /*!
     * Returns the quota of the Cloud service.
     */
    qulonglong quota() const;

    /*!
     * Sets the free amount of the Cloud service
     *
     * \a free the new free amount
     */
    void setFree(qulonglong free);

    /*!
     * Returns the free amount of the Cloud service.
     */
    qulonglong free() const;

    /*!
     * Sets the used amount of the Cloud service
     *
     * \a used the new used amount
     */
    void setUsed(qulonglong used);

    /*!
     * Returns the used amount of the Cloud service.
     */
    qulonglong used() const;

    /*!
     * Sets the relative of the Cloud service
     *
     * \a relative the new relative
     */
    void setRelative(float relative);

    /*!
     * Returns the relative of the Cloud service.
     */
    float relative() const;

    /*!
     * Sets the private key of the Cloud service
     *
     * \a privateKey the new privateKey
     */
    void setKey(const QString &privateKey);

    /*!
     * Returns the private key of the Cloud service.
     */
    QString key() const;

private:
    class Private;
    QSharedDataPointer<Private> d;
};

}

#endif
